import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import React from "react";
import { Dropdown } from "semantic-ui-react";
import { ITEM_SHAPE } from "./items";
import { PureComponent, cloneElement } from "react";
import { arrayOf, func, node, shape, string } from "prop-types";
import { groupBy, isNil } from "lodash";
export class MultiSelectDropdownMenu extends PureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      itemWidth: "auto"
    });

    _defineProperty(this, "handleItemClick", (event, data) => {
      const {
        onItemClick
      } = this.props;
      onItemClick(event, data, this.props);
    });

    _defineProperty(this, "setItemWidth", element => {
      if (!isNil(element)) {
        this.setState({
          itemWidth: element.getBoundingClientRect().width
        });
      }
    });
  }

  renderGroupedItems() {
    const {
      items,
      headerRenderer
    } = this.props;
    const results = [];
    const groups = groupBy(items, x => x.group);
    Object.keys(groups).forEach(key => {
      const group = groups[key];
      const renderedHeader = cloneElement(headerRenderer(key, group), {
        key: key
      });
      results.push(renderedHeader);
      group.forEach(x => {
        const renderedItem = this.renderItem(x, "".concat(x.group, "-").concat(x.value));
        results.push(renderedItem);
      });
    });
    return results;
  }

  renderRegularItems() {
    const {
      items
    } = this.props;
    return items.map(x => this.renderItem(x, x.value));
  }

  renderItem(item, key) {
    const {
      itemRenderer,
      keyboardItem
    } = this.props;
    const {
      itemWidth
    } = this.state;
    const isSelected = !isNil(keyboardItem) && item.value === keyboardItem.value;
    return cloneElement(itemRenderer(item, isSelected), {
      key: key,
      style: {
        minWidth: "".concat(itemWidth, "px")
      },
      onClick: this.handleItemClick
    });
  }

  renderItemSizer() {
    return React.createElement("div", {
      key: "item-sizer",
      className: "o-0 h-0 w-100",
      ref: this.setItemWidth
    });
  }

  renderResults() {
    const {
      items,
      noResultsMessage
    } = this.props;

    if (items.length > 0) {
      let results = [];
      const isGrouped = !isNil(items[0].group);

      if (isGrouped) {
        results = this.renderGroupedItems();
      } else {
        results = this.renderRegularItems();
      }

      results.push(this.renderItemSizer());
      return results;
    }

    return React.createElement("div", {
      className: "pl6 mb4"
    }, noResultsMessage);
  }

  render() {
    const {
      searchInput,
      className
    } = this.props;
    return React.createElement(Dropdown.Menu, {
      className: className
    }, searchInput, React.createElement(Dropdown.Menu, {
      scrolling: true
    }, this.renderResults()));
  }

}